@@ -31,7 +31,7 @@ FacetGrid <- proto(Facet, {
 	
 	examples <- function(.) {
 		# Facetting displays subsets of the data in different panels
-		p <- ggplot(diamonds, aes(x=carat, y=price)) + geom_point()
+		p <- ggplot(diamonds, aes(x=carat, y=price)) + geom_point() + geom_smooth(aes(colour=cut), method="lm") + scale_x_log10() + scale_y_log10()
 		
 		# With one variable
 		p + facet_grid(. ~ cut)
@@ -41,6 +41,7 @@ FacetGrid <- proto(Facet, {
 		# With two variables
 		p + facet_grid(clarity ~ cut)
 		p + facet_grid(cut ~ clarity)
+		p + facet_grid(cut ~ clarity, margins=TRUE)
 		# and only useful if you have a reaaaaaallly long screen
 		p + facet_grid(cut + clarity ~ .)
 		
@@ -48,6 +49,12 @@ FacetGrid <- proto(Facet, {
 		# when writing functions that generate facetting specifications
 		p + facet_grid("cut ~ .")
 		
+		# It still works even if not all panels have data in them
+		airquality$week <- airquality$Day %/% 7
+		qplot(Ozone, Wind, data=airquality, facets = Month ~ week)
+		
+		# see also ?plotmatrix
+		
 	}
 	
 })
