@@ -1,10 +1,10 @@
 GeomBoxplot <- proto(GeomInterval, {
-	draw <- function(., data, ...) {
+	draw <- function(., data, ..., outlier.colour = "red", outlier.shape = 19, outlier.size = 1) {
 		defaults <- with(data, data.frame(x=x, colour=colour, size=size, linetype=1, group=1, xend=x,  width=width, fill=fill, stringsAsFactors=FALSE))
 		defaults2 <- defaults[c(1,1), ]
 		
 		with(data, ggname(.$my_name(), gTree(children = gList(
-			if(length(outliers[[1]]) > 1) GeomPoint$draw(data.frame(y = outliers[[1]], x = x[rep(1, length(outliers[[1]]))], colour=I("red"), shape=shape, size=size), ...),
+			if(length(outliers[[1]]) > 1) GeomPoint$draw(data.frame(y = outliers[[1]], x = x[rep(1, length(outliers[[1]]))], colour=I(outlier.colour), shape=outlier.shape, size=outlier.size), ...),
 			GeomPath$draw(data.frame(y=c(upper, max), defaults2), ...),
 			GeomPath$draw(data.frame(y=c(lower, min), defaults2), ...),
 			GeomBar$draw(data.frame(max = upper, min = lower, defaults), ...),
@@ -25,11 +25,16 @@ GeomBoxplot <- proto(GeomInterval, {
 	
 	default_stat <- function(.) StatBoxplot
 	default_pos <- function(.) PositionDodge
-	default_aes <- function(.) aes(weight=1, colour="grey50", fill="white", size=1, shape=19)
+	default_aes <- function(.) aes(weight=1, colour="grey50", fill="white", size=1)
 	seealso <- list(
 		stat_quantile = "View quantiles conditioned on a continuous variable",
 		geom_jitter = "Another way to look at conditional distributions"
 	)
+	desc_params <- list(
+		outlier.colour = "colour for outlying points",
+		outlier.shape = "shape of outlying points",
+		outlier.size = "size of outlying points"
+	)
 	
 	examples <- function(.) {
 		p <- ggplot(mtcars, aes(y=mpg, x=factor(cyl)))
@@ -39,6 +44,8 @@ GeomBoxplot <- proto(GeomInterval, {
 		p + geom_boxplot() + geom_jitter()
 		p + geom_boxplot() + coord_flip()
 		
+		p + geom_boxplot(outlier.colour = "green", outlier.size = 3)
+		
 		# Add aesthetic mappings
 		p + geom_boxplot(aes(fill=cyl))
 		p + geom_boxplot(aes(fill=factor(cyl)))
