@@ -1,6 +1,6 @@
 GeomJitter <- proto(GeomPoint, {
 	objname <- "jitter"
-	details <- ""
+	details <- "<p>The jitter geom is a convenient default for geom_point + position_jitter.  It is often useful for plotting categorical data.  See position_jitter for more details on adjusting the amount of jittering.</p>"
 	desc <- "Points, jittered to reduce overplotting"
 	icon <- function(.) {
 		pos <- seq(0.1, 0.9, length=6)
@@ -25,14 +25,12 @@ GeomJitter <- proto(GeomPoint, {
 		p + geom_jitter(aes(colour=rating))
 		
 		# Vary parameters
-		p + geom_jitter(xjitter=5)
-		p + geom_jitter(yjitter=5)
+		p + geom_jitter(position=position_jitter(xjitter=5))
+		p + geom_jitter(position=position_jitter(yjitter=5))
 		
 		# Use qplot instead
 		qplot(mpaa, rating, data=movies, geom="jitter")
 		qplot(mpaa, rating, data=movies, geom=c("boxplot","jitter"))
 		qplot(mpaa, rating, data=movies, geom=c("jitter", "boxplot"))
-		qplot(mpaa, rating, data=movies, geom="jitter", xjitter=2)
-		qplot(mpaa, rating, data=movies, geom="jitter", yjitter=1)		
 	}
 })
