@@ -17,4 +17,11 @@ Position <- proto(TopLevel, expr = {
 		cat("position_", .$objname, ": ()", sep="")
 		if (newline) cat("\n")
 	}
+
+	html_returns <- function(.) {
+		ps(
+			"<h2>Returns</h2>\n",
+			"<p>This function returns a position object.</p>"
+		)
+	}
 })
\ No newline at end of file
