@@ -9,17 +9,20 @@
 # 
 # @arguments x values
 # @arguments y values
+# @arguments z values
+# @arguments other arguments passed on to the geom functions
 # @arguments data frame to use (optional)
 # @arguments facetting formula to use
-# @arguments grob type(s) to draw (can be a vector of multiple names)
+# @arguments whether or not margins will be displayed
+# @arguments geom to use (can be a vector of multiple names)
+# @arguments statistic to use (can be a vector of multiple names)
+# @arguments position adjustment to use (can be a vector of multiple names)
 # @arguments limits for x axis (aesthetics to range of data)
 # @arguments limits for y axis (aesthetics to range of data)
 # @arguments which variables to log transform ("x", "y", or "xy")
 # @arguments character vector or expression for plot title
 # @arguments character vector or expression for x axis label
 # @arguments character vector or expression for y axis label
-# @arguments if specified, build on top of this ggplot, rather than creating a new one
-# @arguments other arguments passed on to the geom functions
 # @keyword hplot 
 #X # Use data from data.frame
 #X qplot(mpg, wt, data=mtcars)
@@ -37,11 +40,7 @@
 #X # Use different geoms
 #X qplot(mpg, wt, geom="path")
 #X qplot(factor(cyl), wt, geom=c("boxplot", "jitter"))
-#X 
-#X # Add to an existing plot
-#X p <- qplot(mpg, wt, geom="path")
-#X qplot(mpg, wt, geom="point", add=p)
-qplot <- function(x, y = NULL, z=NULL, ..., data, facets = . ~ ., margins=FALSE, geom = "point", stat=list(NULL), position=list(NULL), xlim = c(NA, NA), ylim = c(NA, NA), log = "", main = NULL, xlab = deparse(substitute(x)), ylab = deparse(substitute(y)), add=NULL) {
+qplot <- function(x, y = NULL, z=NULL, ..., data, facets = . ~ ., margins=FALSE, geom = "point", stat=list(NULL), position=list(NULL), xlim = c(NA, NA), ylim = c(NA, NA), log = "", main = NULL, xlab = deparse(substitute(x)), ylab = deparse(substitute(y))) {
 
 	argnames <- names(as.list(match.call(expand.dots=FALSE)[-1]))
 	arguments <- as.list(match.call()[-1])
@@ -49,11 +48,7 @@ qplot <- function(x, y = NULL, z=NULL, ..., data, facets = . ~ ., margins=FALSE,
 	
 	# Create data if not explicitly specified
 	if (missing(data)) {
-		if (!is.null(add)) {
-			data <- add$data
-		} else {
-			data <- as.data.frame(tryapply(aesthetics, eval, parent.frame(n=2)))
-		}
+		data <- as.data.frame(tryapply(aesthetics, eval, parent.frame(n=2)))
 
 		facetvars <- all.vars(facets)
 		facetvars <- facetvars[facetvars != "."]
@@ -61,12 +56,7 @@ qplot <- function(x, y = NULL, z=NULL, ..., data, facets = . ~ ., margins=FALSE,
 		if (nrow(facetsdf)) data <- cbind(data, facetsdf)
 	}
 
-	# Create new plot, or add to existing?
-	if (is.null(add)) {
-		p <- ggplot(data, aesthetics) + facet_grid(facets=deparse(facets), margins=margins)
-	} else {
-		p <- add
-	}
+	p <- ggplot(data, aesthetics) + facet_grid(facets=deparse(facets), margins=margins)
 	
 	if (!is.null(main)) p$title <- main
 	if (!is.null(xlab)) p$xlabel <- xlab
@@ -82,11 +72,7 @@ qplot <- function(x, y = NULL, z=NULL, ..., data, facets = . ~ ., margins=FALSE,
 
 		params <- arguments[setdiff(names(arguments), c(.all_aesthetics, argnames))]
 		
-		if (is.null(add)) {
-			p <<- p + layer(geom=g, stat=s, geom_params=params, stat_params=params, position=ps)
-		} else {
-			p <<- p + layer(geom=g, stat=s, data=data, aesthetics=aesthetics, geom_params=params, stat_params=params, position=ps)
-		}
+		p <<- p + layer(geom=g, stat=s, geom_params=params, stat_params=params, position=ps)
 	}, geom, stat, position)
 	
 	logv <- function(var) var %in% strsplit(log, "")[[1]]
