@@ -1,6 +1,6 @@
 ScaleGradient <- proto(ScaleContinuous, expr={
 
-	new <- function(., name=NULL, low="darkblue", high="yellow", space="rgb", limits=c(NA,NA), trans="identity", alpha = 1, ..., variable) {
+	new <- function(., name=NULL, low=muted("darkblue"), high="yellow", space="rgb", limits=c(NA,NA), trans="identity", alpha = 1, ..., variable) {
 		if (is.character(trans)) trans <- Trans$find(trans)
 		proto(., name=name, low=low, high=high, space=space, .input=variable, .output=variable, .tr = trans, limits=limits, alpha = alpha, ...)
 	}
@@ -90,20 +90,22 @@ ScaleGradient <- proto(ScaleContinuous, expr={
 })
 
 ScaleGradient2 <- proto(ScaleContinuous, expr={	
-	new <- function(., name=NULL, low="red", mid="white", high="black", midpoint=0, space="rgb", limits=c(NA,NA), trans="identity", alpha=1, ..., variable) {
+	new <- function(., name=NULL, low=muted("red"), mid="white", high=muted("blue"), midpoint=0, space="rgb", limits=c(NA,NA), trans="identity", alpha=1, ..., variable) {
 		if (is.character(trans)) trans <- Trans$find(trans)
 		proto(., name=name, low=low, mid=mid, high=high, midpoint=midpoint, space=space, ..., .input=variable, .output=variable, .tr=trans, limits=limits, alpha=alpha)
 	}
 	
 	map <- function(., x) {
 		rng <- .$frange()  - .$midpoint
+		extent <- max(abs(rng))
+		
 		domain <- .$domain()
 		x[x < domain[1] | x > domain[2]] <- NA
 
 		ramp  <- colorRamp(c(.$low, .$mid, .$high),  space=.$space, interpolate="linear")
 		
 		x <- x - .$midpoint
-		x <- x / ifelse(x < 0, -rng[1], rng[2]) / 2 + 0.5
+		x <- x / extent / 2 + 0.5
 		
 		nice_ramp(ramp, x, .$alpha)
 	}
@@ -139,22 +141,42 @@ ScaleGradient2 <- proto(ScaleContinuous, expr={
 	
 	examples <- function(.) {
 		dsub <- subset(diamonds, x > 5 & x < 6 & y > 5 & y < 6)
-		(d <- qplot(x, y, data=dsub, colour=x-y))
+		dsub$diff <- with(dsub, sqrt(abs(x-y))* sign(x-y))
+		(d <- qplot(x, y, data=dsub, colour=diff))
 		
 		d + scale_colour_gradient2()
 		# Change scale name
-		d + scale_colour_gradient2(expression(x - y))
+		d + scale_colour_gradient2(expression(sqrt(abs(x - y))))
 		d + scale_colour_gradient2("Difference\nbetween\nwidth and\nheight")
 
 		# Change limits and colours
 		d + scale_colour_gradient2(limits=c(-0.2, 0.2))
-		d + scale_colour_gradient2(mid="black", high="yellow", low="yellow")
+
+		# Using "muted" colours makes for pleasant graphics 
+		# (and they have better perceptual properties too)
+		d + scale_colour_gradient2(low="red", high="blue")
+		d + scale_colour_gradient2(low=muted("red"), high=muted("blue"))
+
+		# Using the Lab colour space also improves perceptual properties
+		# at the price of slightly slower operation
+		d + scale_colour_gradient2(space="Lab")
 		
-		# You can also use a non-zero midpoint
+		# About 5% of males are red-green colour blind, so it's a good
+		# idea to avoid that combination
+		d + scale_colour_gradient2(high=muted("green"))
+
+		# We can also make the middle stand out
+		d + scale_colour_gradient2(mid=muted("green"), high="white", low="white")
+		
+		# or use a non zero mid point
 		(d <- qplot(carat, price, data=diamonds, colour=price/carat))
-		d + scale_colour_gradient2(midpoint=mean(diamonds$price / diamonds$carat), high="darkgreen", mid="yellow")
+		d + scale_colour_gradient2(midpoint=mean(diamonds$price / diamonds$carat))
 		
 		# Fill gradients work much the same way
+		p <- qplot(letters[1:5], 1:5, fill= c(-3, 3, 5, 2, -2), geom="bar")
+		p + scale_fill_gradient2("fill")
+		# Note how positive and negative values of the same magnitude
+		# have similar intensity
 	}
 	
 })
